use std::time::Duration;

/// File in storage containing users list
pub const USERS_LIST_FILE: &str = "users.json";

/// File in storage containing clients list
pub const CLIENTS_LIST_FILE: &str = "clients.yaml";

/// Default built-in credentials
pub const DEFAULT_ADMIN_USERNAME: &str = "admin";
pub const DEFAULT_ADMIN_PASSWORD: &str = "admin";

/// App name
pub const APP_NAME: &str = "Basic OIDC";

/// Maximum session duration after inactivity, in seconds
pub const MAX_INACTIVITY_DURATION: i64 = 60 * 30;

/// Maximum session duration (6 hours)
pub const MAX_SESSION_DURATION: i64 = 3600 * 6;

/// Minimum password length
pub const MIN_PASS_LEN: usize = 4;

/// The name of the cookie used to store session information
pub const SESSION_COOKIE_NAME: &str = "auth-cookie";

/// Authenticated routes prefix
pub const AUTHENTICATED_ROUTES: &str = "/settings";

/// Admin routes prefix
pub const ADMIN_ROUTES: &str = "/admin";

/// Auth route
pub const LOGIN_ROUTE: &str = "/login";

/// Bruteforce protection
pub const KEEP_FAILED_LOGIN_ATTEMPTS_FOR: u64 = 3600;
pub const MAX_FAILED_LOGIN_ATTEMPTS: usize = 15;
pub const FAIL_LOGIN_ATTEMPT_CLEANUP_INTERVAL: Duration = Duration::from_secs(60);

/// Temporary password length
pub const TEMPORARY_PASSWORDS_LEN: usize = 20;

/// Open ID routes
pub const AUTHORIZE_URI: &str = "/openid/authorize";

/// Open ID constants
pub const OPEN_ID_SESSION_CLEANUP_INTERVAL: Duration = Duration::from_secs(60);
pub const OPEN_ID_SESSION_LEN: usize = 40;
pub const OPEN_ID_AUTHORIZATION_CODE_LEN: usize = 120;
pub const OPEN_ID_AUTHORIZATION_CODE_TIMEOUT: u64 = 300;
pub const OPEN_ID_TOKEN_LEN: usize = 120;
pub const OPEN_ID_TOKEN_TIMEOUT: u64 = 3600;